QtARMSim
========

QtARMSim is a graphical frontend to the ARMSim ARM simulator. It
provides an easy to use multiplatform ARM emulation environment that
has been designed to be used on Computer Architecture introductory
courses.

It is based on a previous work of Gloria Edo Piñana, who developed
`GlSpim <http://lorca.act.uji.es/project/glspim/>`_ on 2008.  GlSpim
is the graphical part of what was planned to be a Qt graphical
interface to the SPIM simulator.

The ARMSim ARM simulator, Copyright (c) 2014-17 by Germán Fabregat, is
bundled with QtARMSim.  It can be found on the ``armsim/``
subdirectory.
